@@ -1,9 +1,9 @@
 use strict;
 use warnings;
-package Task::Kensho::ExcelCSV; # git description: v0.39-52-ga265614
+package Task::Kensho::ExcelCSV; # git description: v0.40-19-gf5ac869
 # ABSTRACT: A Glimpse at an Enlightened Perl: Excel/CSV
 
-our $VERSION = '0.40';
+our $VERSION = '0.41';
 
 __END__
 
@@ -17,7 +17,7 @@ Task::Kensho::ExcelCSV - A Glimpse at an Enlightened Perl: Excel/CSV
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 SYNOPSIS
 
@@ -66,17 +66,21 @@ facilitates the ease and simplicity the distribution aims to achieve.
 
 =head1 RECOMMENDED MODULES
 
-=for stopwords CSV
+=for stopwords CSV XLS XLSX
 
 =head2 L<Task::Kensho::ExcelCSV>: Excel/CSV
 
-=head3 L<Spreadsheet::ParseExcel::Simple>
+=head3 L<Excel::Writer::XLSX>
 
-A simple interface to Excel data
+Create spreadsheets in the XLSX format
+
+=head3 L<Spreadsheet::Read>
+
+Read the data from a spreadsheet
 
 =head3 L<Spreadsheet::WriteExcel::Simple>
 
-Create Excel documents easily
+Create XLS documents easily
 
 =head3 L<Text::CSV_XS>
 
@@ -108,7 +112,7 @@ starting place on the road to Enlightened Perl programming.
 Please report any bugs or feature requests to
 L<https://github.com/EnlightenedPerlOrganisation/task-kensho/issues>.
 
-bugs may be submitted through L<https://github.com/EnlightenedPerlOrganisation/task-kensho/issues>.
+Bugs may be submitted through L<https://github.com/EnlightenedPerlOrganisation/task-kensho/issues>.
 
 There is also an irc channel available for users of this distribution, at
 L<C<#epo> on C<irc.perl.org>|irc://irc.perl.org/#epo>.
@@ -119,7 +123,7 @@ Chris Prather <chris@prather.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Karen Etheridge Leo Lapworth Chris Nehren Olaf Alders Dan Book Rachel Kelly Shawn Sorichetti Rick Leir
+=for stopwords Karen Etheridge Leo Lapworth Dan Book Chris Nehren Mohammad S Anwar Olaf Alders Rachel Kelly Shawn Sorichetti Rick Leir Tina Müller
 
 =over 4
 
@@ -133,10 +137,18 @@ Leo Lapworth <leo@cuckoo.org>
 
 =item *
 
+Dan Book <grinnz@grinnz.com>
+
+=item *
+
 Chris Nehren <apeiron@cpan.org>
 
 =item *
 
+Mohammad S Anwar <mohammad.anwar@yahoo.com>
+
+=item *
+
 Olaf Alders <olaf@wundersolutions.com>
 
 =item *
@@ -155,6 +167,10 @@ Shawn Sorichetti <shawn@coloredblocks.com>
 
 Rick Leir <rleir@leirtech.com>
 
+=item *
+
+Tina Müller <cpan2@tinita.de>
+
 =back
 
 =head1 COPYRIGHT AND LICENCE
